summaryrefslogtreecommitdiffstats
path: root/src/libsoundmanager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/libsoundmanager.cpp')
-rw-r--r--src/libsoundmanager.cpp9
1 files changed, 3 insertions, 6 deletions
diff --git a/src/libsoundmanager.cpp b/src/libsoundmanager.cpp
index 9ba3e21..5c4ba61 100644
--- a/src/libsoundmanager.cpp
+++ b/src/libsoundmanager.cpp
@@ -185,9 +185,6 @@ int Soundmanager::init_event(){
*
* #### Parameters
* - event_cb [in] : This argument should be specified to the callback for subscribed event
-
-
-
* - reply_cb [in] : This argument should be specified to the reply callback for call function
* - hangup_cb [in] : This argument should be specified to the hangup callback for call function. nullptr is defaulty set.
*
@@ -197,7 +194,7 @@ int Soundmanager::init_event(){
* Event callback is invoked by sound manager for event you subscribed.
* If you would like to get event, please call subscribe function before/after this function
*/
-void Soundmanager::register_callback(
+void Soundmanager::registerCallback(
void (*event_cb)(const string& event, struct json_object* event_contents),
void (*reply_cb)(struct json_object* reply_contents),
void (*hangup_cb)(void))
@@ -208,7 +205,7 @@ void Soundmanager::register_callback(
}
/**
* This function is overload of register_callback. This registers callback function for reply/event message from sound manager
*
* #### Parameters
* - reply_cb [in] : This argument should be specified to the reply callback for call function
@@ -221,7 +218,7 @@ void Soundmanager::register_callback(
* This function for convinience for user uses set_event_handler
* If you would like to get event, please call subscribe function before/after this function
*/
-void Soundmanager::register_callback(
+void Soundmanager::registerCallback(
void (*reply_cb)(struct json_object* reply_contents),
void (*hangup_cb)(void))
{
@@ -208,7 +205,7 @@ void Soundmanager::register_callback(
}
/**
- * This function is overload of register_callback. This registers callback function for reply/event message from sound manager
+ * This function is overload of registerCallback. This registers callback function for reply/event message from sound manager
*
* #### Parameters